<?php namespace Pingpong\Modules\Commands;

use Illuminate\Console\Command;
use Pingpong\Modules\Traits\ModuleCommandTrait;
use Symfony\Component\Console\Input\InputOption;
use Symfony\Component\Console\Input\InputArgument;

class ModuleMigrateResetCommand extends Command {

    use ModuleCommandTrait;

	/**
	 * The console command name.
	 *
	 * @var string
	 */
	protected $name = 'module:migrate-reset';

	/**
	 * The console command description.
	 *
	 * @var string
	 */
	protected $description = 'Reset the modules migrations.';

	/**
	 * Execute the console command.
	 *
	 * @return mixed
	 */
	public function fire()
	{
        $module = $this->getModuleName();

        if( empty($module))
        {
            $this->reset($module);

            return;
        }

        foreach($this->laravel['modules']->all() as $module)
        {
            $this->reset($module);
        }
	}

    /**
     * Rollback migration from the specified module.
     *
     * @param $module
     */
    public function reset($module)
    {
        $path = $this->laravel['modules']->getModulePath($module) . '/Database/Migrations';

        $files = $this->laravel['files']->glob($path . '/*_*.php');

        foreach($files as $file)
        {
            $this->laravel['files']->requireOnce($file);
        }

        $this->call('migrate:reset', [
            '--pretend'     =>  $this->option('pretend'),
            '--database'    =>  $this->option('database'),
            '--force'       =>  $this->option('force'),
        ]);
    }

    /**
     * Get the console command arguments.
     *
     * @return array
     */
    protected function getArguments()
    {
        return array(
            array('module', InputArgument::OPTIONAL, 'The name of module will be used.'),
        );
    }

    /**
     * Get the console command options.
     *
     * @return array
     */
    protected function getOptions()
    {
        return array(
            array('database', null, InputOption::VALUE_OPTIONAL, 'The database connection to use.'),

            array('force', null, InputOption::VALUE_NONE, 'Force the operation to run when in production.'),

            array('pretend', null, InputOption::VALUE_NONE, 'Dump the SQL queries that would be run.'),
        );
    }

}
